unit Main;

interface

uses
  Windows, Messages, SysUtils, {$IFDEF D6PLUS}Variants,{$ENDIF} Classes, Graphics, Controls, Forms,
  Dialogs, Email_Defs, OE_Intf, StdCtrls, ComCtrls, ExtCtrls, Menus, ImgList;

type
  Twnd_oe_Main = class(TForm)
    od: TOpenDialog;
    sb: TStatusBar;
    MainMenu: TMainMenu;
    File1: TMenuItem;
    mmOpen: TMenuItem;
    N1: TMenuItem;
    mmExit: TMenuItem;
    N2: TMenuItem;
    mmSave: TMenuItem;
    List: TListView;
    sd: TSaveDialog;
    N3: TMenuItem;
    mmView: TMenuItem;
    procedure cmOpen(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cmExit(Sender: TObject);
    procedure ListAdvancedCustomDrawItem(Sender: TCustomListView;
      Item: TListItem; State: TCustomDrawState; Stage: TCustomDrawStage;
      var DefaultDraw: Boolean);
    procedure ListAdvancedCustomDrawSubItem(Sender: TCustomListView;
      Item: TListItem; SubItem: Integer; State: TCustomDrawState;
      Stage: TCustomDrawStage; var DefaultDraw: Boolean);
    procedure FormShow(Sender: TObject);
    procedure cmSave(Sender: TObject);
    procedure cmView(Sender: TObject);
  private
  public
    OEReader: TOEReader;
    procedure OpenFile(Afilename: string);
  end;

var
  wnd_oe_Main: Twnd_oe_Main;

implementation

uses View;

{$R *.dfm}


procedure Twnd_oe_Main.cmOpen(Sender: TObject);
begin
  if od.Execute then
    OpenFile(od.FileName);
end;

procedure Twnd_oe_Main.FormCreate(Sender: TObject);
begin
  OEReader:=nil;
end;

procedure Twnd_oe_Main.cmExit(Sender: TObject);
begin
  Close;
end;

procedure Twnd_oe_Main.ListAdvancedCustomDrawItem(Sender: TCustomListView;
  Item: TListItem; State: TCustomDrawState; Stage: TCustomDrawStage;
  var DefaultDraw: Boolean);
begin
  if Item.ImageIndex=-2 then
    Sender.Canvas.Font.Style:=[fsBold]
  else
    Sender.Canvas.Font.Style:=[];
end;

procedure Twnd_oe_Main.ListAdvancedCustomDrawSubItem(
  Sender: TCustomListView; Item: TListItem; SubItem: Integer;
  State: TCustomDrawState; Stage: TCustomDrawStage;
  var DefaultDraw: Boolean);
begin
  if Item.ImageIndex=-2 then
    Sender.Canvas.Font.Style:=[fsBold]
  else
    Sender.Canvas.Font.Style:=[];
end;

procedure Twnd_oe_Main.FormShow(Sender: TObject);
begin
  if FileExists(ParamStr(1)) then
    OpenFile(ParamStr(1));
end;

procedure Twnd_oe_Main.OpenFile(Afilename: string);
var
  i: Integer;
  s: string;
  mi: TMessageInfo;
begin
  Screen.Cursor:=crHourglass;
  List.Items.BeginUpdate;
  List.Items.Clear;
  sb.Panels[0].Text:='Loading...';
  Update;
  if Assigned(OEReader) then
    FreeAndNil(OEReader);
  try
    with TOEReader.Create do
      try
        LoadFromFile(AFileName);
        case FileType of
          oe4: OEReader:=TMBXReader.Create;
          oe5: OEReader:=TDBXReader.Create;
        end;
      finally
        Free;
      end;
    if not Assigned(OEReader) then
      raise EOEReaderException.Create('File is not in supported format.');
    OEReader.LoadFromFile(Afilename);
    OEReader.ReadMessages;
    if OEReader.Loaded then begin
      for i:=0 to OEReader.MessageCount-1 do
        with List.Items.Add do begin
          mi:=OEReader.MessageInfos[i];
          if mi.Flags and mifRead=mifRead then
            ImageIndex:=-1
          else
            ImageIndex:=-2;
          Caption:='';
          SubItems.Add(IntToStr(i));
          if mi.Flags and mifAttachment=mifAttachment then
            SubItems.Add('Yes')
          else
            SubItems.Add('');
          case mi.Priority of
            1: SubItems.Add('High');
            5: SubItems.Add('Low');
            else
              SubItems.Add('');
          end;
          if mi.Flags and mifFlag=mifFlag then
            SubItems.Add('Yes')
          else
            SubItems.Add('');
          if mi.SenderName='' then
            s:=mi.SenderEmail
          else
            s:=mi.SenderName;
          SubItems.Add(s);
          SubItems.Add(mi.Subject);
          SubItems.Add(DatetimeToStr(mi.ReceivedDate));
          SubItems.Add(Format('%1.0n',[mi.Size/1]));
        end;
    end;
  finally
    Caption:=Format('OE Demo - [%s]',[OEReader.Foldername]);
    Application.Title:=Caption;
    sb.Panels[0].Text:=Format('Count: %d',[OEReader.MessageCount]);
    sb.Panels[1].Text:=OEReader.FileName;;
    List.Items.EndUpdate;
    Screen.Cursor:=crDefault;
  end;
end;

procedure Twnd_oe_Main.cmSave(Sender: TObject);
var
  sl: TStringList;
begin
  if sd.Execute then begin
    sl:=TStringList.Create;
    sb.Panels[0].Text:='Saving...';
    Update;
    Screen.Cursor:=crHourglass;
    try
      sl.Text:=OEReader.Messages[StrToInt(List.Selected.SubItems[0])];
      sl.SaveToFile(sd.FileName);
    finally
      sl.Free;
      sb.Panels[0].Text:=Format('Count: %d',[OEReader.MessageCount]);
      Screen.Cursor:=crDefault;
    end;
  end;
end;

procedure Twnd_oe_Main.cmView(Sender: TObject);
begin
  if Assigned(List.Selected) then
    ShowView(OEReader.Messages[StrToInt(List.Selected.SubItems[0])]);
end;

end.
